==> zio-aws-groundstation_3-5.17.193.1-sources.jar: zio/aws/groundstation/model/DeleteMissionProfileResponse.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeleteMissionProfileResponse(
    missionProfileId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse = {
    import DeleteMissionProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
      .builder()
      .optionallyWith(missionProfileId.map(value => value: java.lang.String))(
        _.missionProfileId
      )
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.DeleteMissionProfileResponse.ReadOnly =
    zio.aws.groundstation.model.DeleteMissionProfileResponse
      .wrap(buildAwsValue())
}
object DeleteMissionProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.DeleteMissionProfileResponse =
      zio.aws.groundstation.model
        .DeleteMissionProfileResponse(missionProfileId.map(value => value))
    def missionProfileId: Optional[String]
    def getMissionProfileId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("missionProfileId", missionProfileId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
  ) extends zio.aws.groundstation.model.DeleteMissionProfileResponse.ReadOnly {
    override val missionProfileId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.missionProfileId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
  ): zio.aws.groundstation.model.DeleteMissionProfileResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-groundstation_3-6.20.115.1-sources.jar: zio/aws/groundstation/model/DeleteMissionProfileResponse.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeleteMissionProfileResponse(
    missionProfileId: Optional[Uuid] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse = {
    import DeleteMissionProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
      .builder()
      .optionallyWith(
        missionProfileId.map(value => Uuid.unwrap(value): java.lang.String)
      )(_.missionProfileId)
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.DeleteMissionProfileResponse.ReadOnly =
    zio.aws.groundstation.model.DeleteMissionProfileResponse
      .wrap(buildAwsValue())
}
object DeleteMissionProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.DeleteMissionProfileResponse =
      zio.aws.groundstation.model
        .DeleteMissionProfileResponse(missionProfileId.map(value => value))
    def missionProfileId: Optional[Uuid]
    def getMissionProfileId: ZIO[Any, AwsError, Uuid] =
      AwsError.unwrapOptionField("missionProfileId", missionProfileId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
  ) extends zio.aws.groundstation.model.DeleteMissionProfileResponse.ReadOnly {
    override val missionProfileId: Optional[Uuid] = zio.aws.core.internal
      .optionalFromNullable(impl.missionProfileId())
      .map(value => zio.aws.groundstation.model.primitives.Uuid(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteMissionProfileResponse
  ): zio.aws.groundstation.model.DeleteMissionProfileResponse.ReadOnly =
    new Wrapper(impl)
}
